' *************************************************************************
'					(C) Copyright OMRON CORPORATION 2011
'							All Rights Reserved
' ---------------------------------------------------------------------------
'					Application Producer for FJ series
' *************************************************************************
' Filename    : VB_DisplayBarChart_settng.vb
' Description : Template source for MDI Child Window form
' *************************************************************************
Public Class VB_DisplayBarChart

    '**********************************************************************
    ' Definition of setting data.
    '**********************************************************************
    <Serializable()> _
    Public Class DataDef

        ' Code example :
        Public unitNo As Integer

    End Class

    Private Shared sumMeasurement As Integer
    Private Shared sumOK As Integer
    Private Shared sumNG As Integer


    '**********************************************************************
    ' Definition of default value of setting data.
    '**********************************************************************
    Public Shared Shadows ReadOnly Property DefaultSetting() As DataDef
        Get
            Dim dataSet As New DataDef

            '(1)
            dataSet.unitNo = 1

            'sumMeasurement = 0
            'sumOK = 0
            'sumNG = 0

            Return dataSet
        End Get
    End Property

    '**********************************************************************
    ' title         : Apply setting data
    ' function name : SettingDataChange
    ' parameters    : none
    ' description   :
    '       This function is called on starting form, or closed setting form
    '       with OK button.
    '       In this function, setting parameters should be extracted from
    '       Me.SettingData and applied.
    '**********************************************************************
    Protected Overrides Sub SettingDataChange()
        MyBase.SettingDataChange()
        Dim dataSet As DataDef = StringToObj(Me.SettingData)

        '******************************************************************
        ' Apply setting data.
        '******************************************************************
        'Code example
        'Me.Label1.Text = dataSet.DataA
        'Me.Label2.Text = dataSet.DataB.ToString

    End Sub

    '**********************************************************************
    ' title         : Save setting data
    ' function name : MakeSettingData
    ' parameters    : none
    ' description   :
    '       This function is called when "Data Save" is executed, or opening
    '       setting form.
    '       In this function, setting parameters should be converted to 
    '       string and set to Me.SettingData.
    '**********************************************************************
    Protected Overrides Sub MakeSettingData()
        MyBase.MakeSettingData()
        Dim dataSet As New DataDef

        ' *****************************************************************
        ' Set setting data to dataSet object.
        ' *****************************************************************
        'Code example
        'dataSet.DataA = Me.Label1.Text
        'dataSet.DataB.ToString = Me.Label2.Text

        Me.SettingData = ObjToString(dataSet)
    End Sub

    '**********************************************************************
    ' title         : Load the MDI window message string data
    ' function name : SetMessageText
    ' parameters    : none
    ' description   :
    '       This subroutine is called when this form is loaded.
    '       In this subroutine, the message text strings are aquired
    '       and applied to controls.
    '**********************************************************************

    Protected Overrides Sub SetMessageText()
        MyBase.SetMessageText()
        OpenTextData("VB_DisplayBarChart")

        ' *****************************************************************
        ' Set message text.
        ' *****************************************************************

        ' Code example :
        ' Label1.Text = GetText("MessageTitle")

    End Sub

    '**********************************************************************
    ' title         : Measurement initialization procedure
    ' function name : MeasureInitProc
    ' parameters    : none
    ' description   :
    '       This subroutine is called on each measurement initialization time.
    '**********************************************************************
    Public Overrides Sub MeasureInitProc()
        MyBase.MeasureInitProc()


    End Sub

    '**********************************************************************
    ' title         : Measurement display procedure
    ' function name : MeasureDispProc
    ' parameters    : none
    ' description   :
    '       This subroutine is called on each measurement display time.
    '**********************************************************************
    Public Overrides Sub MeasureDispProc()
        MyBase.MeasureDispProc()

        '(2)
        Call DispGraph()
    End Sub

    '**********************************************************************
    ' title         : Scene change procedure
    ' function name : SceneChangeProc
    ' parameters    : inital
    '                   True  : Switched to new scene.
    '                   False : Switched to existing scene.
    ' description   :
    '       This subroutine is called when scene is switched.
    '**********************************************************************
    Public Overrides Sub SceneChangeProc(ByVal initial As Boolean)
        MyBase.SceneChangeProc(initial)
    End Sub

    '**********************************************************************
    ' These modules are for converting DataDef.
    '**********************************************************************
    Public Shared Function ObjToString(ByVal obj As DataDef) As String

        Dim bf As New System.Runtime.Serialization.Formatters.Binary.BinaryFormatter
        'Dim ms As New System.IO.MemoryStream
        Dim outputStream As New System.IO.FileStream("c:\\MDI_setting.dat", System.IO.FileMode.Create)

        'bf.Serialize(ms, obj)
        Try
            bf.Serialize(outputStream, obj)
        Finally
            outputStream.Close()
        End Try

        'Dim str As String = System.Convert.ToBase64String(ms.ToArray)
        Dim str As String = ""
        Return str
    End Function

    Public Shared Function StringToObj(ByVal strData As String) As DataDef
        Dim dataSet As New DataDef
        'Dim testString As String

        Dim fileFlg As Boolean = System.IO.File.Exists("c:\\MDI_setting.dat")
        If fileFlg = False Then
            dataSet = DefaultSetting
        Else
            Dim inputStream As New System.IO.FileStream("c:\\MDI_setting.dat", System.IO.FileMode.Open)
            Dim bf As New System.Runtime.Serialization.Formatters.Binary.BinaryFormatter
            Try
                dataSet = CType(bf.Deserialize(inputStream), DataDef)
            Finally
                inputStream.Close()
            End Try

            If dataSet Is Nothing Then
                dataSet = DefaultSetting
            End If

        End If

        Return dataSet
        'If (String.IsNullOrEmpty(strData)) Then
        '    Return Nothing
        'End If
        'Dim bf As New System.Runtime.Serialization.Formatters.Binary.BinaryFormatter
        'Dim ms As New System.IO.MemoryStream(System.Convert.FromBase64String(strData))
        'Return bf.Deserialize(ms)
    End Function
    Private Sub DispGraph()
        Dim dataSet As DataDef = StringToObj(Me.SettingData)
        Dim result As Integer

        '(3)
        result = FZ_FormBase.FZ_FormBase.GetUnitJudge(dataSet.unitNo)
        sumMeasurement = sumMeasurement + 1

        '(4)
        If result = 1 Then
            sumOK = sumOK + 1
        ElseIf result = -1 Then
            sumNG = sumNG + 1
        End If


        With Chart1
            '(5)
            .Series.Clear()

            '(6)
            Dim ChartName As String
            ChartName = "Total"
            .Series.Add(ChartName)
            ChartName = "OK"
            .Series.Add(ChartName)
            ChartName = "NG"
            .Series.Add(ChartName)

            .Series(0).Points.Add(sumMeasurement)
            .Series(1).Points.Add(sumOK)
            .Series(2).Points.Add(sumNG)

            '(7)
            .ChartAreas(0).RecalculateAxesScale()
        End With

    End Sub
End Class